@@ -101,6 +101,11 @@ AS_INTERNAL_VISIBLE
 gboolean		as_is_empty (const gchar *str);
 GDateTime		*as_iso8601_to_datetime (const gchar *iso_date);
 
+AS_INTERNAL_VISIBLE
+gboolean		as_str_verify_integer (const gchar *str,
+						gint64 min_value,
+						gint64 max_value);
+
 AS_INTERNAL_VISIBLE
 gboolean		as_utils_delete_dir_recursive (const gchar* dirname);
 
