@@ -91,9 +91,14 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 	  N_("The description contains a web URL in plain text. This is not allowed, please use the <url/> tag instead to share links.")
 	},
 
+	{ "tag-not-translatable",
+	  AS_ISSUE_SEVERITY_ERROR,
+	  N_("This tag is not translatable.")
+	},
+
 	{ "tag-duplicated",
 	  AS_ISSUE_SEVERITY_ERROR,
-	  N_("As per AppStream specification, the mentioned tag must only appear once in this context. Having multiple tags of this kind is not valid.")
+	  N_("This tag must only appear once in this context. Having multiple tags of this kind is not valid.")
 	},
 
 	{ "tag-empty",
@@ -342,6 +347,23 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 	  N_("This `hardware` item contains an invalid value. It should be a Computer Hardware ID (CHID) UUID without braces.")
 	},
 
+	{ "relation-memory-value-invalid",
+	  AS_ISSUE_SEVERITY_WARNING,
+	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
+	  N_("A `memory` item must only contain a non-zero integer value, depicting a system memory size in mebibyte (MiB)")
+	},
+
+	{ "relation-internet-value-invalid",
+	  AS_ISSUE_SEVERITY_WARNING,
+	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
+	  N_("The set tag value is not valid for an `internet` relation.")
+	},
+
+	{ "relation-internet-bandwidth-value-invalid",
+	  AS_ISSUE_SEVERITY_WARNING,
+	  N_("The value of this property must be a positive integer value, describing the minimum required bandwidth in mbit/s.")
+	},
+
 	{ "component-type-invalid",
 	  AS_ISSUE_SEVERITY_ERROR,
 	  N_("The set component type is not a recognized, valid AppStream component type.")
@@ -462,6 +484,11 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 	  N_("This web link uses the FTP protocol. Consider switching to HTTP(S) instead."),
 	},
 
+	{ "url-redefined",
+	  AS_ISSUE_SEVERITY_WARNING,
+	  N_("An URL of this type has already been defined."),
+	},
+
 	{ "developer-name-has-url",
 	  AS_ISSUE_SEVERITY_WARNING,
 	  N_("The <developer_name/> can not contain a hyperlink."),
