@@ -106,7 +106,7 @@ test_readwrite_yaml_news ()
 		"      </description>\n"
 		"    </release>\n"
 		"    <release type=\"stable\" version=\"1.1\" date=\"2019-04-12T00:00:00Z\">\n"
-		"      <description translatable=\"no\">\n"
+		"      <description translate=\"no\">\n"
 		"        <p>A freeform description text.</p>\n"
 		"        <p>Second paragraph. XML &lt;&gt; YAML</p>\n"
 		"        <ul>\n"
@@ -117,7 +117,7 @@ test_readwrite_yaml_news ()
 		"      </description>\n"
 		"    </release>\n"
 		"    <release type=\"stable\" version=\"1.0\" date=\"2019-02-24T00:00:00Z\">\n"
-		"      <description translatable=\"no\">\n"
+		"      <description translate=\"no\">\n"
 		"        <ul>\n"
 		"          <li>Introduced feature A</li>\n"
 		"          <li>Introduced feature B</li>\n"
